%This code is associated with the publication:
%"Harmonic radar tracking reveals that honeybee drones navigate between multiple aerial leks"
%by: Joseph L. Woodgate, James C. Makinson, Natacha Rossi, Ka S. Lim,
%Andrew M. Reynolds, Christopher J. Rawlings, Lars Chittka 
%2021, iScience
%
%This script reproduces all data analyses in the publication
%To run this script you must first derive the necessary variables by running another script:
%"HoneybeeDroneTracking_ProcessData.m"
%
%All code written  by Joseph Woodgate, 2021
%
%This code requires dataset:
%"HoneybeeDroneTracking_ProcessedData.mat"
%archived at:
%
%or the output of "HoneybeeDroneTracking_ProcessData.m"
%archived at:
%

%% User inputs
plotfigures=0; %1 to create all panels for Figures 5, 6, S4-8; 0 to suppress Figure plotting
plottables=1; %1 to display Tables S1, S2; 0 to suppress Table printing

%%
%Create summary text to keep track of results
summary=cellstr({});
%summary=[summary; cellstr([ ])];

%%
%Find N for number of substantial flight segments and number of different
%drones
summary=[summary; cellstr(['"Use of the landscape by drones"'])];
summary=[summary; cellstr(['N total substantial segments: ' num2str(length(DroneFlightSegments.SegmentNo)) ])];
summary=[summary; cellstr(['N minimum number of unique drones (not all flights could be assigned to a drone so a greater number of drones may actually be represented in the dataset): ' num2str(length(unique(DroneFlightSegments.BeeID))) ])];
summary=[summary; cellstr([''])];
%%
summary=[summary; cellstr(['_______________________________________________'])];
summary=[summary; cellstr(['"Identifying potential drone congregation areas"'])];
summary=[summary; cellstr([''])];

%Number and duration of convoluted flights
summary=[summary; cellstr(['N total convoluted flight sections: ' num2str(sum(DroneFlightSegments.ConvolutedSectionCount)) ])];
summary=[summary; cellstr(['N flight segments containing convoluted sections: ' num2str(sum(DroneFlightSegments.ConvolutedSectionCount>0)) ])];
summary=[summary; cellstr(['Percentage of flight segments containing convoluted sections: ' num2str(((sum(DroneFlightSegments.ConvolutedSectionCount>0))/(length(DroneFlightSegments.SegmentNo)))*100, 3)])];
summary=[summary; cellstr(['N flight segments containing multiple convoluted sections: ' num2str(sum(DroneFlightSegments.ConvolutedSectionCount>1)) ])];
summary=[summary; cellstr(['Percentage of flight segments with at least one convoluted section that have multiple section: ' num2str(((sum(DroneFlightSegments.ConvolutedSectionCount>1))/(sum(DroneFlightSegments.ConvolutedSectionCount>0)))*100, 3)])];
summary=[summary; cellstr([''])];

summary=[summary; cellstr(['Mean duration of convoluted sections (s): ' num2str(mean(seconds(DroneConvolutedFlights.Duration)), 4) ' +/- ' num2str((std(seconds(DroneConvolutedFlights.Duration))/sqrt(length(DroneConvolutedFlights.Duration))),3) ])];
    durationpercent=100*seconds(DroneFlightSegments.DurationConvolutedSections)./seconds(DroneFlightSegments.Duration);
summary=[summary; cellstr(['Mean percentage of flight duration accounted for by convoluted flight sections: ' num2str(mean(durationpercent(DroneFlightSegments.ConvolutedSectionCount>0)),3) ' +/- ' num2str(std(durationpercent(DroneFlightSegments.ConvolutedSectionCount>0)) / sqrt(length(durationpercent(DroneFlightSegments.ConvolutedSectionCount>0))),2)])];
summary=[summary; cellstr([''])];

%%
%No congregations identified
summary=[summary; cellstr(['N congregation areas identified by cluster analysis: ' num2str(length(Congregations.IDNo)) ])];
summary=[summary; cellstr([''])];

%%
summary=[summary; cellstr(['_______________________________________________'])];
summary=[summary; cellstr(['"Orientation flight and route development"'])];
summary=[summary; cellstr([''])];

%Orientation flights
summary=[summary; cellstr(['N complete orientation flights (those in which the drone returned to the hive at the end of the flight): ' num2str(sum(DroneFlightSegments.Orientation==1 & DroneFlightSegments.EndLocation>0)) ])];
summary=[summary; cellstr(['Orientation flights: Mean maximum distance from start (m): ' num2str(round(mean(DroneFlightSegments.DistanceMax(DroneFlightSegments.Orientation==1 & DroneFlightSegments.EndLocation>0)),1)) ' +/- ' num2str(round( ((std(DroneFlightSegments.DistanceMax(DroneFlightSegments.Orientation==1 & DroneFlightSegments.EndLocation>0)))/(sqrt(sum(DroneFlightSegments.Orientation==1 & DroneFlightSegments.EndLocation>0)))),1))])];
summary=[summary; cellstr(['Orientation flights: Mean duration (s): ' num2str(round(mean(seconds(DroneFlightSegments.Duration(DroneFlightSegments.Orientation==1 & DroneFlightSegments.EndLocation>0))),1)) ' +/- ' num2str(round( ((std(seconds(DroneFlightSegments.Duration(DroneFlightSegments.Orientation==1 & DroneFlightSegments.EndLocation>0))))/(sqrt(sum(DroneFlightSegments.Orientation==1 & DroneFlightSegments.EndLocation>0)))),1))])];

 ubees=unique(DroneFlightSegments.BeeID);
 nosegmentsperbee=zeros(size(ubees));
 startedwithorientation=zeros(size(ubees));
 startedwithcompleteorientation=zeros(size(ubees));
 for bind=1:length(ubees)
    thisbee=find(DroneFlightSegments.BeeID==ubees(bind));
    nosegmentsperbee(bind)=length(thisbee);
    if any(DroneFlightSegments.Orientation(thisbee)==1)
        startedwithorientation(bind)=1;
    end
    if any(DroneFlightSegments.Orientation(thisbee)==1 & DroneFlightSegments.EndLocation(thisbee)>0)
        startedwithcompleteorientation(bind)=1;
    end
     
 end
 multibees=find(nosegmentsperbee>=6 & startedwithcompleteorientation==1 & ubees<1000)  ;
summary=[summary; cellstr(['N individuals with a complete record of 6 or more flights : ' num2str(length(multibees)) ])];
summary=[summary; cellstr(['Maximum number of flights by a bee with complete flight record : ' num2str(max(nosegmentsperbee(multibees))) ])];
summary=[summary; cellstr([''])];

%%
summary=[summary; cellstr(['_______________________________________________'])];
summary=[summary; cellstr(['"Dynamics of drone flight at hives and congregation areas"'])];
summary=[summary; cellstr([''])];

%No flight segments with multiple congregation area visits
summary=[summary; cellstr(['N flight segments containing congregation area visits: ' num2str(sum(sum(DroneFlightSegments.LocationsVisited(:,1:4),2) >0)) ])];
summary=[summary; cellstr(['Percentage of flight segments containing congregation area visits: ' num2str(((sum(sum(DroneFlightSegments.LocationsVisited(:,1:4),2) >0))/(length(DroneFlightSegments.SegmentNo)))*100, 3)])];
summary=[summary; cellstr(['N flight segments visiting multiple congregation areas: ' num2str(sum(sum(DroneFlightSegments.LocationsVisited(:,1:4),2) >1)) ])];
summary=[summary; cellstr(['Percentage of flight segments with at least one comngregation area visit that have multiple visits: ' num2str(((sum(sum(DroneFlightSegments.LocationsVisited(:,1:4),2) >1))/(sum(sum(DroneFlightSegments.LocationsVisited(:,1:4),2) >0)))*100, 3)])];
summary=[summary; cellstr([''])];

%%
%Linear regressions: acceleration conditioned on position relative to Location 
axisxlimits=[-105, 105];
axisylimits=[-10 10];
%%
temptable=[];
for pind=1:length(Locations.IDNo)
    plotind=DroneFlightPaths.ConvolutedSectionLocation==pind;
    tempresults=accelplot(DroneFlightPaths.PositionXComponent, DroneFlightPaths.AccelerationXComponent, plotind, axisxlimits, axisylimits,1);
    temptable=[temptable;tempresults];
    
    tempresults=accelplot(DroneFlightPaths.PositionYComponent, DroneFlightPaths.AccelerationYComponent, plotind, axisxlimits, axisylimits,1);
    temptable=[temptable;tempresults];
end
%%
tablelocations=sort(repmat((1:length(Locations.IDNo))',2,1));
TableS2.Location=Locations.Name(tablelocations);
TableS2.Direction=repmat({'X';'Y'},length(Locations.IDNo),1);
TableS2.Slope=round(temptable(:,1),3);
TableS2.YIntercept=round(temptable(:,2),2);
TableS2.XIntercept=round(temptable(:,3),2);
TableS2.Rsquared=round(temptable(:,4),2);
TableS2.F=round(temptable(:,5),2);
TableS2.DF1=temptable(:,6);
TableS2.DF2=temptable(:,7)*1000;
TableS2.P=round(temptable(:,8),4);
TableS2=struct2table(TableS2);
%
summary=[summary; cellstr(['Mean x-intercept for X-components of regression of acceleration on position (m): ' num2str(mean(TableS2.XIntercept(1:2:end)),3) ' +/- ' num2str((std(TableS2.XIntercept(1:2:end)))/(sqrt(length(Locations.IDNo))),3)])];
summary=[summary; cellstr(['Mean x-intercept for Y-components of regression of acceleration on position (m): ' num2str(mean(TableS2.XIntercept(2:2:end)),3) ' +/- ' num2str((std(TableS2.XIntercept(2:2:end)))/(sqrt(length(Locations.IDNo))),3)])];
summary=[summary; cellstr([''])];

%%
%ANOVAs on Kurtosis of position, velocity distributions relative to Location

var=[Locations.KurtosisPositionX Locations.KurtosisPositionY];
TKurtosisPosition = array2table([var(:), [zeros(size(var,1),1);  ones(size(var,1),1)], repmat(Locations.CongregationOrHive-1,2,1), [(1:length(Locations.IDNo))' ; (1:length(Locations.IDNo))']],'VariableNames',{'ResponseVariable', 'XorY', 'CongregationOrHive', 'LocationID'});
[~, kpositionstats, ~]=anovan(TKurtosisPosition.ResponseVariable, [TKurtosisPosition.CongregationOrHive TKurtosisPosition.XorY [1;2;3;4;1;2;3;1;2;3;4;1;2;3]], 'random', [3], 'varnames', {'Congregation or Hive' 'X or Y' 'Location ID'}, 'model', 'linear', 'nested', [0 0 0; 0 0 0;1 0 0]);

var=[Locations.KurtosisVelocityX Locations.KurtosisVelocityY];
TKurtosisVelocity = array2table([var(:), [zeros(size(var,1),1);  ones(size(var,1),1)], repmat(Locations.CongregationOrHive-1,2,1), [(1:length(Locations.IDNo))' ; (1:length(Locations.IDNo))']],'VariableNames',{'ResponseVariable', 'XorY', 'CongregationOrHive', 'LocationID'});
[~, kvelocitystats, ~]=anovan(TKurtosisVelocity.ResponseVariable, [TKurtosisVelocity.CongregationOrHive TKurtosisVelocity.XorY [1;2;3;4;1;2;3;1;2;3;4;1;2;3]], 'random', [3], 'varnames', {'Congregation or Hive' 'X or Y' 'Location ID'}, 'model', 'linear', 'nested', [0 0 0; 0 0 0;1 0 0]);

summary=[summary; cellstr(['Results of ANOVA on kurtosis of position distribution: Congregations vs Hives: F(' num2str(kpositionstats{2,3}) ',' num2str(kpositionstats{5,3}) ') = ' num2str(round(kpositionstats{2,6},2)) '; P = ' num2str(round(kpositionstats{2,7},3))])];
summary=[summary; cellstr(['Results of ANOVA on kurtosis of velocity distribution: Congregations vs Hives: F(' num2str(kvelocitystats{2,3}) ',' num2str(kvelocitystats{5,3}) ') = ' num2str(round(kvelocitystats{2,6},2)) '; P = ' num2str(round(kvelocitystats{2,7},3))])];
summary=[summary; cellstr(['Results of ANOVA on kurtosis of position distribution: X vs Y: F(' num2str(kpositionstats{3,3}) ',' num2str(kpositionstats{5,3}) ') = ' num2str(round(kpositionstats{3,6},2)) '; P = ' num2str(round(kpositionstats{3,7},3))])];
summary=[summary; cellstr(['Results of ANOVA on kurtosis of velocity distribution: X vs Y: F(' num2str(kvelocitystats{3,3}) ',' num2str(kvelocitystats{5,3}) ') = ' num2str(round(kvelocitystats{3,6},2)) '; P = ' num2str(round(kvelocitystats{3,7},3))])];
summary=[summary; cellstr([''])];

%%
%Mean flight speed during straight flight sections

%Find starts and ends of straight flight sections
datapointsinstraightsections=find(DroneFlightPaths.ConvolutedSectionNoGlobal==0);
straightends=find(diff(datapointsinstraightsections)>1);
straightstarts=[1; datapointsinstraightsections(straightends+1)];
straightends=[datapointsinstraightsections(straightends); length(DroneFlightPaths.ConvolutedSectionLocation)];
%Find starts and ends of flight segments
segmentstarts=NaN(size(DroneFlightSegments.SegmentNo));
segmentends=NaN(size(DroneFlightSegments.SegmentNo));
useg=unique(DroneFlightPaths.SegmentNo);
for sind=1:length(useg)
   thisseg=find(DroneFlightPaths.SegmentNo==useg(sind));
   segmentstarts(sind)=thisseg(1);
   segmentends(sind)=thisseg(end);
end
%Ensure that no proposed straight section incorporates data from multiple flight
%segments
for pind=1:length(straightstarts)
    segmentstartsmidvisit=find(segmentstarts>straightstarts(pind) & segmentstarts<=straightends(pind));
    if isempty(segmentstartsmidvisit)==0
        addstarts=segmentstarts(segmentstartsmidvisit);
        addends=segmentends(segmentstartsmidvisit);
        addends(end)=straightends(pind);
        
        straightends(pind)=segmentends(segmentstartsmidvisit(1)-1);
        straightstarts=[straightstarts; addstarts];
        straightends=[straightends; addends];
    end
    
end
%Put straight sections into chronological order
[straightstarts, straightsort]=sort(straightstarts);
straightends=straightends(straightsort);
%Calculate speeds
straightsectionspeedmean=NaN(size(straightstarts));
straightsectionspeedsd=NaN(size(straightstarts));
for sind=1:length(straightstarts)
    thissection=straightstarts(sind):straightends(sind);
   straightsectionspeedmean(sind)=mean(DroneFlightPaths.SpeedStep(thissection(2:end)));
   straightsectionspeedsd(sind)=std(DroneFlightPaths.SpeedStep(thissection(2:end)));
end
straightspeedmean=nanmean(straightsectionspeedmean);
straightspeedse=nanstd(straightsectionspeedmean) / sqrt(length(straightsectionspeedmean));

%%
%ANOVAs on mean speed and duration of convoluted flight at congregations
%and hives

 convolutedsectionsatanylocation=find(DroneConvolutedFlights.Location~=0);
TDurationSpeed.Duration=seconds(DroneConvolutedFlights.Duration(convolutedsectionsatanylocation));
TDurationSpeed.Speed=DroneConvolutedFlights.SpeedMean(convolutedsectionsatanylocation);
TDurationSpeed.CongregationOrHive=DroneConvolutedFlights.CongregationOrHive(convolutedsectionsatanylocation)-1;
TDurationSpeed.LocationID=DroneConvolutedFlights.Location(convolutedsectionsatanylocation);
TDurationSpeed.LocationIDNested=TDurationSpeed.LocationID; TDurationSpeed.LocationIDNested(TDurationSpeed.LocationID>4)=TDurationSpeed.LocationID(TDurationSpeed.LocationID>4)-4;
TDurationSpeed.SegmentNo=DroneConvolutedFlights.SegmentNo(convolutedsectionsatanylocation);
TDurationSpeed.BeeID=DroneFlightSegments.BeeID(TDurationSpeed.SegmentNo);
TDurationSpeed=struct2table(TDurationSpeed);
[~, durationstats, ~]=anovan(TDurationSpeed.Duration, [TDurationSpeed.CongregationOrHive TDurationSpeed.LocationIDNested TDurationSpeed.BeeID], 'random', [2 3], 'nested', [0 0 0 ; 1 0 0  ; 0 0 0 ], 'varnames', {'CongregationOrHive' 'LocationID' 'BeeID'}, 'model', 'linear');
[~, speedstats, ~]=anovan(TDurationSpeed.Speed, [TDurationSpeed.CongregationOrHive TDurationSpeed.LocationIDNested TDurationSpeed.BeeID], 'random', [2 3], 'nested', [0 0 0 ; 1 0 0  ; 0 0 0 ], 'varnames', {'CongregationOrHive' 'LocationID' 'BeeID'}, 'model', 'linear');

durationcongregationmean=mean(TDurationSpeed.Duration(TDurationSpeed.CongregationOrHive==0));
 durationcongregationse=(std(TDurationSpeed.Duration(TDurationSpeed.CongregationOrHive==0))) / sqrt(sum(TDurationSpeed.CongregationOrHive==0));
 durationhivemean=mean(TDurationSpeed.Duration(TDurationSpeed.CongregationOrHive==1));
 durationhivese=(std(TDurationSpeed.Duration(TDurationSpeed.CongregationOrHive==1))) / sqrt(sum(TDurationSpeed.CongregationOrHive==1));
 speedcongregationmean=mean(TDurationSpeed.Speed(TDurationSpeed.CongregationOrHive==0));
 speedcongregationse=(std(TDurationSpeed.Speed(TDurationSpeed.CongregationOrHive==0))) / sqrt(sum(TDurationSpeed.CongregationOrHive==0));
 speedhivemean=mean(TDurationSpeed.Speed(TDurationSpeed.CongregationOrHive==1));
 speedhivese=(std(TDurationSpeed.Speed(TDurationSpeed.CongregationOrHive==1))) / sqrt(sum(TDurationSpeed.CongregationOrHive==1));

summary=[summary; cellstr(['Mean flight speed during convoluted sections of flight located at congregation areas (m/s): ' num2str(round(speedcongregationmean,2)) ' +/- ' num2str(round(speedcongregationse,2))])];
summary=[summary; cellstr(['Mean flight speed during convoluted sections of flight located at hives (m/s): ' num2str(round(speedhivemean,2)) ' +/- ' num2str(round(speedhivese,2))])];
summary=[summary; cellstr(['Results of ANOVA on flight speed: Congregations vs Hives: F(' num2str(speedstats{2,3}) ',' num2str(speedstats{5,3}) ') = ' num2str(round(speedstats{2,6},2)) '; P = ' num2str(round(speedstats{2,7},3))])];
summary=[summary; cellstr(['c.f. Mean flight speed during straight sections of flight (m/s): ' num2str(round(straightspeedmean,2)) ' +/- ' num2str(round(straightspeedse,2))])];

summary=[summary; cellstr(['Mean duration of convoluted sections of flight located at congregation areas (s): ' num2str(round(durationcongregationmean,1)) ' +/- ' num2str(round(durationcongregationse,1))])];
summary=[summary; cellstr(['Mean duration of convoluted sections of flight located at hives (s): ' num2str(round(durationhivemean,1)) ' +/- ' num2str(round(durationhivese,1))])];
summary=[summary; cellstr(['Results of ANOVA on duration: Congregations vs Hives: F(' num2str(durationstats{2,3}) ',' num2str(durationstats{5,3}) ') = ' num2str(round(durationstats{2,6},2)) '; P = ' num2str(round(durationstats{2,7},3))])];
summary=[summary; cellstr([''])];

%%
%ANOVAs on mean speed and duration of convoluted flight at congregations,
%looking for differences between congregations 

[~, durationcongregationstats, durationcongregationoutput]=anovan(TDurationSpeed.Duration(TDurationSpeed.LocationID<5), [TDurationSpeed.LocationIDNested(TDurationSpeed.LocationID<5) TDurationSpeed.BeeID(TDurationSpeed.LocationID<5)], 'random', [2], 'varnames', {'LocationID' 'BeeID'}, 'model', 'linear');
[~, speedcongregationstats, speedcongregationoutput]=anovan(TDurationSpeed.Speed(TDurationSpeed.LocationID<5), [TDurationSpeed.LocationIDNested(TDurationSpeed.LocationID<5) TDurationSpeed.BeeID(TDurationSpeed.LocationID<5)], 'random', [2], 'varnames', {'LocationID' 'BeeID'}, 'model', 'linear');
speedcongregationcomparison = multcompare(speedcongregationoutput);
summary=[summary; cellstr(['Results of ANOVA on duration: differences between congregations: F(' num2str(durationcongregationstats{2,3}) ',' num2str(durationcongregationstats{4,3}) ') = ' num2str(round(durationcongregationstats{2,6},2)) '; P = ' num2str(round(durationcongregationstats{2,7},3))])];
summary=[summary; cellstr(['Results of ANOVA on flight speed: differences between congregations: F(' num2str(speedcongregationstats{2,3}) ',' num2str(speedcongregationstats{4,3}) ') = ' num2str(round(speedcongregationstats{2,6},2)) '; P = ' num2str(round(speedcongregationstats{2,7},3))])];
     sigcomparison=find(speedcongregationcomparison(:,6)<0.05);
    for sind=1:length(sigcomparison)
        summary=[summary; cellstr(['Results of Tukey''s test: ' num2str(speedcongregationcomparison(sigcomparison(sind),1)) ' vs '  num2str(speedcongregationcomparison(sigcomparison(sind),2)) '; P = ' num2str(round(speedcongregationcomparison(sigcomparison(sind),6),3))])];
    end
summary=[summary; cellstr(['Results of Tukey''s test: all other comparisons P > 0.05'])];
summary=[summary; cellstr([''])];

%%
summary=[summary; cellstr(['_______________________________________________'])];
summary=[summary; cellstr(['"Virgin queen flight"'])];
summary=[summary; cellstr([''])];

%Details of queen flight
summary=[summary; cellstr(['Maximum number of flights made by any queen: ' num2str(max(QueenFlightSegments.BeeFlightNo))])];
summary=[summary; cellstr(['First flights: Mean maximum distance from start (m): ' num2str(round(mean(QueenFlightSegments.DistanceMax(QueenFlightSegments.BeeFlightNo==1)),1)) ' +/- ' num2str(round( ((std(QueenFlightSegments.DistanceMax(QueenFlightSegments.BeeFlightNo==1)))/(sqrt(sum(QueenFlightSegments.BeeFlightNo==1)))),1))])];
    timeinflight=3*QueenFlightSegments.DataPointCount; %Queens often sat on the outside of the hive for long periods so the flight durations don't accurately reflect how long they were flying. Instead we use a proxy figure derived from the number of radar detections of the bee
    fixtime=seconds(timeinflight); fixtime.Format='hh:mm:ss';

summary=[summary; cellstr(['First flights: Mean time in flight (s): ' num2str(round(mean(timeinflight(QueenFlightSegments.BeeFlightNo==1)),1)) ' +/- ' num2str(round( ((std(timeinflight(QueenFlightSegments.BeeFlightNo==1)))/(sqrt(sum(QueenFlightSegments.BeeFlightNo==1)))),1))])];
    [~,lastflight,~]=unique(QueenFlightSegments.BeeID,'last');
    hiflight=QueenFlightSegments.BeeFlightNo(lastflight);
summary=[summary; cellstr(['Mean number of flights made by each queen: ' num2str(round(mean(hiflight),1)) ' +/- ' num2str(round( ((std(hiflight))/(sqrt(length(hiflight)))),1))])];
summary=[summary; cellstr(['Number of second and subsequent flights: ' num2str(sum(QueenFlightSegments.BeeFlightNo>1))])];
summary=[summary; cellstr(['Second and subsequent flights: Mean maximum distance from start (m): ' num2str(round(mean(QueenFlightSegments.DistanceMax(QueenFlightSegments.BeeFlightNo>1)),1)) ' +/- ' num2str(round( ((std(QueenFlightSegments.DistanceMax(QueenFlightSegments.BeeFlightNo>1)))/(sqrt(sum(QueenFlightSegments.BeeFlightNo>1)))),1))])];
summary=[summary; cellstr(['Second and subsequent flights: Mean time in flight (s): ' num2str(round(mean(timeinflight(QueenFlightSegments.BeeFlightNo>1)),1)) ' +/- ' num2str(round( ((std(timeinflight(QueenFlightSegments.BeeFlightNo>1)))/(sqrt(sum(QueenFlightSegments.BeeFlightNo>1)))),1))])];
summary=[summary; cellstr([''])];

%%
summary=[summary; cellstr(['_______________________________________________'])];
summary=[summary; cellstr(['"Methods"'])];
summary=[summary; cellstr([''])];
summary=[summary; cellstr(['N substantial flight segments representing complete flights: ' num2str(sum(DroneFlightSegments.FlightType==1))])];
summary=[summary; cellstr(['N substantial flight segments representing outbound flights: ' num2str(sum(DroneFlightSegments.FlightType==2))])];
summary=[summary; cellstr(['N substantial flight segments representing return flights: ' num2str(sum(DroneFlightSegments.FlightType==3))])];
summary=[summary; cellstr(['N substantial flight segments that could not be assigned to any hive: ' num2str(sum(DroneFlightSegments.FlightType==0))])];
summary=[summary; cellstr([''])];

%%
%Display summary of analysis results
disp(char(summary));

%% CREATE FIGURES
if plotfigures==1
    
    %%
    %Panels for Figure 5
    %Binned acceleration plots
    %Parameters
    locationdata=DroneFlightPaths.ConvolutedSectionLocation;
    xlims=[-105 105];
    ylims=[-5.5 5.5];
    binsize=5;

    %Panel A: X-direction, congregations
    locationstouse=[1 2 3 4];
    xdata=DroneFlightPaths.PositionXComponent;
    ydata=DroneFlightPaths.AccelerationXComponent;
    meanaccelplot(xdata, ydata, locationdata, locationstouse, xlims, ylims, binsize);

    %Panel B: Y-direction, congregations
    locationstouse=[1 2 3 4];
    xdata=DroneFlightPaths.PositionYComponent;
    ydata=DroneFlightPaths.AccelerationYComponent;
    meanaccelplot(xdata, ydata, locationdata, locationstouse, xlims, ylims, binsize);

    %Panel C: X-direction, hives
    locationstouse=[5 6 7];
    xdata=DroneFlightPaths.PositionXComponent;
    ydata=DroneFlightPaths.AccelerationXComponent;
    meanaccelplot(xdata, ydata, locationdata, locationstouse, xlims, ylims, binsize);

    %Panel D: Y-direction, hives
    locationstouse=[5 6 7];
    xdata=DroneFlightPaths.PositionYComponent;
    ydata=DroneFlightPaths.AccelerationYComponent;
    meanaccelplot(xdata, ydata, locationdata, locationstouse, xlims, ylims, binsize);

    %%
    %Panels for Figure 6

    % Panel A: Position Kurtosis boxplots
    var=[Locations.KurtosisPositionX Locations.KurtosisPositionY];
    figure;
    rv=var(:);
    cat=[repmat(Locations.CongregationOrHive-1,2,1), [zeros(size(var,1),1);  ones(size(var,1),1)]]; %Congregation or Hive, X or Y
    dlim=[0 35];
    boxplot(rv, cat, 'Colors', 'k', 'Symbol', '. k', 'Widths', 0.5); %, 'DataLim', dlim);
    set(gca, 'XTick', [], 'XTickLabel', {});
    set(gca, 'YLim', dlim);
    axis square;

    % Panel B: Velocity Kurtosis boxplots
    var=[Locations.KurtosisVelocityX Locations.KurtosisVelocityY];
    figure;
    rv=var(:);
    cat=[repmat(Locations.CongregationOrHive-1,2,1), [zeros(size(var,1),1);  ones(size(var,1),1)]]; %Congregation or Hive, X or Y
    dlim=[0 35];
    boxplot(rv, cat, 'Colors', 'k', 'Symbol', '. k', 'Widths', 0.5); %, 'DataLim', dlim);
    set(gca, 'XTick', [], 'XTickLabel', {});
    set(gca, 'YLim', dlim);
    axis square;

    %Panel C: Duration boxplots, Congregations vs Hives
    figure;
    dlim=[0 390];
    rv=TDurationSpeed.Duration;
    cat=TDurationSpeed.CongregationOrHive;
    boxplot(rv, cat, 'Colors', 'k', 'Symbol', '. k', 'Widths', 0.5); %, 'DataLim', dlim);
    set(gca, 'XTick', [], 'XTickLabel', {});
    set(gca, 'YLim', dlim);
    axis square;

    %Panel D: Speed boxplots, Congregations vs Hives
    figure;
    dlim=[0 11.2];
    rv=TDurationSpeed.Speed;
    cat=TDurationSpeed.CongregationOrHive;
    boxplot(rv, cat, 'Colors', 'k', 'Symbol', '. k', 'Widths', 0.5); %, 'DataLim', dlim);
    set(gca, 'XTick', [], 'XTickLabel', {});
    set(gca, 'YLim', dlim);
    axis square;

    %Panel E: Duration boxplots, differences between Congregations
    figure;
    dlim=[0 390];
    rv=TDurationSpeed.Duration(TDurationSpeed.LocationID<5);
    cat=TDurationSpeed.LocationID(TDurationSpeed.LocationID<5);
    boxplot(rv, cat, 'Colors', 'k', 'Symbol', '. k', 'Widths', 0.5); %, 'DataLim', dlim);
    set(gca, 'XTick', [], 'XTickLabel', {});
    set(gca, 'YLim', dlim);
    axis square;

    %Panel F: Speed boxplots, differences between Congregations
    figure;
    dlim=[0 11.2];
    rv=TDurationSpeed.Speed(TDurationSpeed.LocationID<5);
    cat=TDurationSpeed.LocationID(TDurationSpeed.LocationID<5);
    boxplot(rv, cat, 'Colors', 'k', 'Symbol', '. k', 'Widths', 0.5); %, 'DataLim', dlim);
    set(gca, 'XTick', [], 'XTickLabel', {});
    set(gca, 'YLim', dlim);
    axis square;

    %%
    %Panels for Figure S4

    %Panels A-N: Scatter plots for regressions
    axisxlimits=[-105, 105];
    axisylimits=[-10 10];

    temptable=[];
    for pind=1:length(Locations.IDNo)
        %%
        plotind=DroneFlightPaths.ConvolutedSectionLocation==pind;
        tempresults=accelplot(DroneFlightPaths.PositionXComponent, DroneFlightPaths.AccelerationXComponent, plotind, axisxlimits, axisylimits);
        temptable=[temptable;tempresults];

        tempresults=accelplot(DroneFlightPaths.PositionYComponent, DroneFlightPaths.AccelerationYComponent, plotind, axisxlimits, axisylimits);
        temptable=[temptable;tempresults];
    end

    %Panel O: Locations of centres of mass for each convoluted flight
    %Parameters
    outlinecolour=[0.3 0.3 0.3];
    scalebarlength=200;   


    figure; hold all
    axis equal;
     set(gca,'xtick',[],'ytick',[]);
     set(gca,'XColor','none');
     set(gca,'YColor','none');
     set(gca,'Box','off');
     %Scatter CoMs
    scatter(DroneConvolutedFlights.CoMX(DroneConvolutedFlights.Location==1),DroneConvolutedFlights.CoMY(DroneConvolutedFlights.Location==1),60,'filled','r') ;
    scatter(DroneConvolutedFlights.CoMX(DroneConvolutedFlights.Location==2),DroneConvolutedFlights.CoMY(DroneConvolutedFlights.Location==2),60,'filled','g') ;
    scatter(DroneConvolutedFlights.CoMX(DroneConvolutedFlights.Location==3),DroneConvolutedFlights.CoMY(DroneConvolutedFlights.Location==3),60,'filled','b') ;
    scatter(DroneConvolutedFlights.CoMX(DroneConvolutedFlights.Location==4),DroneConvolutedFlights.CoMY(DroneConvolutedFlights.Location==4),60,'filled','m') ;
     %Keep track of XY values to work out axis limits later
     figurexy=[DroneConvolutedFlights.CoMX(DroneConvolutedFlights.Location>0 & DroneConvolutedFlights.Location<5) DroneConvolutedFlights.CoMY(DroneConvolutedFlights.Location>0 & DroneConvolutedFlights.Location<5)];
     %Plot congregation outlines
    for cind=1:length(Congregations.CoMX)
        thiscongregationvertices=Congregations.HullVerticesXY{cind};
        figurexy=[figurexy; thiscongregationvertices];
    plot(thiscongregationvertices(:,1), thiscongregationvertices(:,2), 'Color', outlinecolour, 'LineWidth', 5) ;
    end
     %Scatter congregation CoMs
    scatter(Congregations.CoMX, Congregations.CoMY, 150, 'filled', 'MarkerFaceColor', outlinecolour)
     %Set axis limits and figure size
    maxxy=max(figurexy,[],1);
    minxy=min(figurexy,[],1);
       buffer=0.05*(maxxy(1)-minxy(1));
       bmaxx=maxxy(1)+buffer;
       bmaxy=maxxy(2)+buffer;
       bminx=minxy(1)-buffer;
       bminy=minxy(2)-buffer;
        ratio =(bmaxx-bminx)/(maxxy(2)-minxy(2));
        height=700;
       set(gcf, 'Position', [488 56 height*ratio height]);
      %Add scale bar
     scalestart=[minxy(1) minxy(2)+buffer];
     scaleend=[scalestart(1)+scalebarlength scalestart(2)];
     plot([scalestart(1) scaleend(1)],[scalestart(2) scaleend(2)], 'k', 'LineWidth', 12);
     %Set axes
     axis([minxy(1) maxxy(1) minxy(2) maxxy(2)]);
     axis equal;

    %%
    %Panels for Figure S5
    %Histogram and normal probability plots for Position distributions of
    %convoluted flight at each congregation

    %Parameters
    positionlimits=[-105 105];
    positionbinsize=5;
    positionbinedges=positionlimits(1):positionbinsize:positionlimits(end);

    for cind=1:4
    histplot(DroneFlightPaths.PositionXComponent, DroneFlightPaths.ConvolutedSectionLocation==cind, positionbinedges);
    histplot(DroneFlightPaths.PositionYComponent, DroneFlightPaths.ConvolutedSectionLocation==cind, positionbinedges);
    end

    %%
    %Panels for Figure S6
    %Histogram and normal probability plots for Velocity distributions of
    %convoluted flight at each congregation

    %Parameters
    velocitylimits=[-17.5 17.5];
    velocitybinsize=1;
    velocitybinedges=velocitylimits(1):velocitybinsize:velocitylimits(end);

    for cind=1:4
    histplot(DroneFlightPaths.VelocityXComponent, DroneFlightPaths.ConvolutedSectionLocation==cind, velocitybinedges);
    histplot(DroneFlightPaths.VelocityYComponent, DroneFlightPaths.ConvolutedSectionLocation==cind, velocitybinedges);
    end

    %%
    %Panels for Figure S7
    %Histogram and normal probability plots for Position distributions of
    %convoluted flight at each hive

    %Parameters
    positionlimits=[-105 105];
    positionbinsize=5;
    positionbinedges=positionlimits(1):positionbinsize:positionlimits(end);

    for cind=5:7
    histplot(DroneFlightPaths.PositionXComponent, DroneFlightPaths.ConvolutedSectionLocation==cind, positionbinedges);
    histplot(DroneFlightPaths.PositionYComponent, DroneFlightPaths.ConvolutedSectionLocation==cind, positionbinedges);
    end

    %%
    %Panels for Figure S8
    %Histogram and normal probability plots for Velocity distributions of
    %convoluted flight at each congregation

    %Parameters
    velocitylimits=[-17.5 17.5];
    velocitybinsize=1;
    velocitybinedges=velocitylimits(1):velocitybinsize:velocitylimits(end);

    for cind=5:7
    histplot(DroneFlightPaths.VelocityXComponent, DroneFlightPaths.ConvolutedSectionLocation==cind, velocitybinedges);
    histplot(DroneFlightPaths.VelocityYComponent, DroneFlightPaths.ConvolutedSectionLocation==cind, velocitybinedges);
    end

%%
end

%% Make Tables
if plottables==1
    
    %%
    %Table S1
    TableS1.Location=Locations.Name;
    TableS1.GPSLat=cell(size(TableS1.Location));
    TableS1.GPSLong=cell(size(TableS1.Location));
    TableS1.Years=cell(size(TableS1.Location));
    TableS1.HivesContributing=cell(size(TableS1.Location));
    TableS1.NoConvolutedSections=NaN(size(TableS1.Location));
    TableS1.NoFlights=NaN(size(TableS1.Location));
    TableS1.DurationMean=NaN(size(TableS1.Location));
    TableS1.DurationSE=NaN(size(TableS1.Location));
    TableS1.SpeedMean=NaN(size(TableS1.Location));
    TableS1.SpeedSE=NaN(size(TableS1.Location));

    tempGPSLat=degrees2dm(Locations.GPSLat);
    tempGPSLong=degrees2dm(Locations.GPSLong); 
    
    for lind=1:length(TableS1.Location)
         segmentsatlocation=unique(DroneFlightPaths.SegmentNo(DroneFlightPaths.ConvolutedSectionLocation==lind));
         convolutedsectionsatlocation=unique(DroneFlightPaths.ConvolutedSectionNoGlobal(DroneFlightPaths.ConvolutedSectionLocation==lind));
         hivesatlocation=max([DroneFlightSegments.StartLocation(segmentsatlocation) DroneFlightSegments.EndLocation(segmentsatlocation)],[], 2);
         hivesatlocation(hivesatlocation==0)=[];
        TableS1.GPSLat{lind}=[num2str(tempGPSLat(lind,1)) char(176) ' ' num2str(tempGPSLat(lind,2),6) ''' N'] ;
        TableS1.GPSLong{lind}=[num2str(tempGPSLong(lind,1)) char(176) ' ' num2str(abs(tempGPSLong(lind,2)),6) ''' W'] ;
        TableS1.Years{lind}=num2str(unique(DroneFlightSegments.Year(segmentsatlocation))');
        TableS1.HivesContributing{lind}=num2str(unique(hivesatlocation)');
        TableS1.NoConvolutedSections(lind)=length(unique(convolutedsectionsatlocation));
        TableS1.NoFlights(lind)=length(unique(segmentsatlocation));
        TableS1.DurationMean(lind)=round(mean(seconds(DroneConvolutedFlights.Duration(convolutedsectionsatlocation))),1);
        TableS1.DurationSE(lind)=round((std(seconds(DroneConvolutedFlights.Duration(convolutedsectionsatlocation)))) / sqrt(length(convolutedsectionsatlocation)),1);
        TableS1.SpeedMean(lind)=round(mean(DroneConvolutedFlights.SpeedMean(convolutedsectionsatlocation)),2);
        TableS1.SpeedSE(lind)=round((std(DroneConvolutedFlights.SpeedMean(convolutedsectionsatlocation))) / sqrt(length(convolutedsectionsatlocation)),2);
    end
    TableS1=struct2table(TableS1);

    disp(TableS1);

    %%
    %Table S2
    disp(TableS2);

%%
end


%% Functions used in figure plotting
%%
function results=accelplot(xdata, ydata, plotind, xlims, ylims, suppressfig)
if nargin<6
    suppressfig=0;
end
%%Eliminate nans and select data to plot
datatouse=isnan(xdata)==0 & isnan(ydata)==0 & plotind==1 & xdata~=Inf & xdata~=-Inf  & ydata~=Inf & ydata~=-Inf;

%fit GLM to data
[p,s]=polyfit(xdata(datatouse), ydata(datatouse),1);
stats=fitlm(xdata(datatouse), ydata(datatouse));
anstats=anova(stats);

results=[p(1) p(2) -p(2)/p(1) stats.Rsquared.Ordinary table2array(anstats(1,4)) table2array(anstats(1,2)) table2array(anstats(2,2))/1000 table2array(anstats(1,5))];

if suppressfig~=1
    %make fig
    figure; hold all;
    axis([xlims ylims]);
    %plot reference lines at 0
    plot(xlims, [0 0], '--', 'Color', [0.7 0.7 0.7]);
    plot([0 0], ylims, '--', 'Color', [0.7 0.7 0.7]);
    %plot data
    scatter(xdata(datatouse), ydata(datatouse), [],[0.4 0.4 0.4], '.');
    %plot best fit line
    bfx=xlims;
    bfy=(p(1)*bfx) + p(2);
    plot(bfx,bfy,'k:');

    axis square;

end
end

%%
function meanaccelplot(xdata, ydata, sheddata, dcastouse, xlims, ylims, binsize)
%%
bootsize=100;
binledges=xlims(1):binsize:xlims(2)-binsize;
binredges=xlims(1)+binsize:binsize:xlims(2);
bincenters=binledges+((binledges-binredges)/2);
binmeanaccel=zeros(length(binledges), length(dcastouse))*NaN;
binupperCI=zeros(length(binledges), length(dcastouse))*NaN;
binlowerCI=zeros(length(binledges), length(dcastouse))*NaN;
binSD=zeros(length(binledges), length(dcastouse))*NaN;
binSE=zeros(length(binledges), length(dcastouse))*NaN;
alldatameanaccel=zeros(length(binledges), 1)*NaN;
alldataupperCI=zeros(length(binledges), 1)*NaN;
alldatalowerCI=zeros(length(binledges), 1)*NaN;
alldataSD=zeros(length(binledges), 1)*NaN;
alldataSE=zeros(length(binledges), 1)*NaN;
alldata=isnan(xdata)==0 & isnan(ydata)==0 & xdata~=Inf & xdata~=-Inf  & ydata~=Inf & ydata~=-Inf;
    allx=xdata(alldata);
    ally=ydata(alldata);
  for bind=1:length(binledges)
      if length(ally(allx>=binledges(bind) & allx<binredges(bind)))>1
        tempallci=bootci(bootsize,@nanmean,ally(allx>=binledges(bind) & allx<binredges(bind)));
       alldatameanaccel(bind)=nanmean(ally(allx>=binledges(bind) & allx<binredges(bind)));
        alldatalowerCI(bind)=tempallci(1);
        alldataupperCI(bind)=tempallci(2);
       alldataSD(bind)=nanstd(ally(allx>=binledges(bind) & allx<binredges(bind)));
       alldataSE(bind)=(nanstd(ally(allx>=binledges(bind) & allx<binredges(bind)))) / sqrt(length(ally(allx>=binledges(bind) & allx<binredges(bind))));
      else
       alldatameanaccel(bind)=NaN;
        alldatalowerCI(bind)=NaN;
        alldataupperCI(bind)=NaN;
       alldataSD(bind)=NaN;
       alldataSE(bind)=NaN;

      end
    for dind=1:length(dcastouse)   
       datatouse=isnan(xdata)==0 & isnan(ydata)==0 & sheddata==dcastouse(dind) & xdata~=Inf & xdata~=-Inf  & ydata~=Inf & ydata~=-Inf;
       tempx=xdata(datatouse);
       tempy=ydata(datatouse);
       if sum(tempx>=binledges(bind) & tempx<binredges(bind))>1
       binmeanaccel(bind,dind)=nanmean(tempy(tempx>=binledges(bind) & tempx<binredges(bind)));
        tempci=bootci(bootsize,@nanmean,tempy(tempx>=binledges(bind) & tempx<binredges(bind)));
       binlowerCI(bind,dind)=tempci(1);
       binupperCI(bind,dind)=tempci(2);
       binSD(bind,dind)=nanstd(tempy(tempx>=binledges(bind) & tempx<binredges(bind)));
       binSE(bind,dind)=(nanstd(tempy(tempx>=binledges(bind) & tempx<binredges(bind)))) / (sqrt(length(tempy(tempx>=binledges(bind) & tempx<binredges(bind)))));

       elseif  sum(tempx>=binledges(bind) & tempx<binredges(bind))>0
       binmeanaccel(bind,dind)=nanmean(tempy(tempx>=binledges(bind) & tempx<binredges(bind)));
       binlowerCI(bind,dind)=NaN;
       binupperCI(bind,dind)=NaN;
       binSD(bind,dind)=NaN;
       binSE(bind,dind)=NaN;
       else
       binmeanaccel(bind,dind)=NaN;
       binlowerCI(bind,dind)=NaN;
       binupperCI(bind,dind)=NaN;
       binSD(bind,dind)=NaN;
       binSE(bind,dind)=NaN;
       end
     end %dind=1:length(dcastouse)
  end %for bind=1:length(binledges)
%%
%make fig
figure; hold all;
axis([xlims ylims]);

%plot reference lines at 0
plot(xlims, [0 0], '--', 'Color', [0.7 0.7 0.7]);
plot([0 0], ylims, '--', 'Color', [0.7 0.7 0.7]);

%plot best fit line
    polyx=repmat(bincenters', length(dcastouse),1);
    polyy=binmeanaccel(:);
    polyuse=isnan(polyy)==0 & polyy~=Inf & polyy~=-Inf;
[p,s]=polyfit(polyx(polyuse), polyy(polyuse),1);
bfx=xlims;
bfy=(p(1)*bfx) + p(2);
plot(bfx,bfy, ':', 'Color', [0.4 0.4 0.4], 'LineWidth', 1.5);

colorlist=['m';'r';'g';'b'];
%plot data lines 
for dind=1:length(dcastouse)
usebins=find(isnan(binlowerCI(:,dind))==0 & isnan(binupperCI(:,dind))==0);
dindcol=colorlist(mod(dind,length(colorlist))+1);
    xtoplot=bincenters;
    ytoplot=binmeanaccel(:,dind);
    plotthese=zeros(size(ytoplot));
    plotthese(usebins)=1;
    plotthese(isnan(ytoplot)==1)=0; %Ignore NaNs
    plotthese(ytoplot>ylims(2) | ytoplot<ylims(1))=0; %For appearance sake don't plot dps that exceed the axis limits
    plot(xtoplot(plotthese==1), ytoplot(plotthese==1), 'LineWidth', 1.5,  'Color', dindcol);
    
    %Plot SEM bars for each DCA
    for uind=1:length(usebins)
       plot([bincenters(usebins(uind)) bincenters(usebins(uind))],[binmeanaccel(usebins(uind),dind)-binSE(usebins(uind),dind) binmeanaccel(usebins(uind),dind)+binSE(usebins(uind), dind)], 'Color', dindcol) ;
    end

end %for dind=1:length(dcastouse)
axis square;
end

%%
function histplot(xdata, plotind, histbins)
%%Eliminate nans and select data to plot
datatouse=isnan(xdata)==0 & plotind==1 & xdata~=Inf & xdata~=-Inf;
%make fig
figure; hold all;
histogram(xdata(datatouse),histbins, 'EdgeColor', 'none', 'FaceColor', [0.2 0.2 0.2]);
axis square;

% %normplot
figure;
np=normplot(xdata(datatouse));
axis([min(histbins) max(histbins) -3.7913 3.7913]);
np(1).Marker='.';
np(1).Color=[0 0 0];
np(1).MarkerSize=15;

% np(2).Color=[0.2 0.2 0.2];
% np(2).LineStyle='--';
delete(np(2));
np(3).Color=[0.2 0.2 0.2];
np(3).LineStyle='--';
yto=get(gca, 'YTick');
    yt=yto([1, 3, 6, 7, 8, 9, 10, 13, 15]);
    ytl={'0.001', '0.010', '0.100', '0.250', '0.500', '0.750' , '0.900', '0.990', '0.999'};
set(gca, 'YTick', yt, 'YTickLabel', ytl); %, 'XLabel', {}, 'YLabel', {});

tlab=get(gca, 'Title');
tlab.String='';
set(gca, 'Title', tlab);
xlab=get(gca, 'XLabel');
xlab.String='';
set(gca, 'XLabel', xlab);
ylab=get(gca, 'YLabel');
ylab.String='';
set(gca, 'YLabel', ylab);

axis square;
end
